/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.crop.clm;

import java.io.ByteArrayInputStream;
import java.util.logging.Logger;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;

/**
 * Un marshaler for un marshaling CropMessage objects
 * @author Merijn Zengers
 */
public class ClmUnmarshaller {
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.stock.type");    
    private static final String PACKAGE_NAME = "nl.cloudfarming.client.crop.clm";
    
    
    /**
     * Unmarshal String containing xml to a CropMessage object
     * @param XML the String to unmarshall
     * @return A CropMessage entity
     */
    public CropMessage unMarshall(String XML){
        JAXBContext jc;
        CropMessage created = null;
        try {
            jc = JAXBContext.newInstance(PACKAGE_NAME);
            Unmarshaller unmarshaller = jc.createUnmarshaller();
            ByteArrayInputStream in = new ByteArrayInputStream(XML.getBytes());
            
            JAXBElement element = (JAXBElement) unmarshaller.unmarshal(in);
            created = (CropMessage) element.getValue();
        } catch (JAXBException ex) {
            LOGGER.fine("Failed to convert xml from webservice to CropMessage object. " + ex.toString());
        }
        return created;
    }
}
